ChMuxError

Enum ChMuxError 

pub enum ChMuxError<SinkError, StreamError> {
    SinkError(SinkError),
    StreamError(StreamError),
    StreamClosed,
    Reset,
    Timeout,
    Protocol(String),
}
Channel multiplexer error.

Variants



SinkError(SinkError)

An error was encountered while sending data to the transport sink.



StreamError(StreamError)

An error was encountered while receiving data from the transport stream.



StreamClosed

The transport stream was closed while multiplex channels were active or the multiplex client was not dropped.



Reset

The connection was reset by the remote endpoint.



Timeout

No messages where received over the configured connection timeout.



Protocol(String)

A multiplex protocol error occurred.