AcceptGuard

Struct AcceptGuard 

pub struct AcceptGuard { /* private fields */ }
Allows a tentatively accepted connection to be rejected afterwards.

Dropping this guard confirms the connection.

Implementations

Source

impl AcceptGuard

pub fn accept(self)

Confirms the connection that was tentatively accepted.

This is equivalent to dropping the guard.

pub async fn reject(self, no_ports: bool)

Rejects the connection that was tentatively accepted.

Setting no_ports to true indicates to the remote endpoint that the request was rejected because no local port could be allocated.

The requester observes this like the rejection of a pre-connected port, i.e. its sender and receiver fail with SendError::Rejected and RecvError::Rejected. Data that was already exchanged over the port is discarded.

The sender and receiver of the tentatively accepted port should be dropped, since the requester is only notified when the port is closed.